# -*- coding: utf-8 -*-

import os
import codecs

from docutils.core import publish_parts
from flask import Flask
from flask import render_template
from flask import request
from flask.ext.babel import gettext as _
from flask.ext.babel import Babel
from config import LANGUAGES
from sayings import get_saying


LANGUAGE_SELECTED = "de"
#ToDo after engelish is implemented set LANGUAGE_SELECTED = None

app = Flask(__name__)
babel = Babel(app)

app.config['BABEL_DEFAULT_LOCALE'] = 'de'


def get_content(filename, overrides=None):
    content = u""
    if os.path.isfile(filename):
        with codecs.open(filename, 'r', 'utf-8') as f:
            rst_data = f.read()
        f.close()
        content = publish_parts(rst_data, writer_name='html', settings_overrides=overrides)['html_body']
    return content

def get_topmenue():
    menue = [('/eskp', _(u'ESKP')),
              ('/ozoneloss', _(u'Ozoneloss')),
              ('/iek-7', _(u'IEK-7')),
            ]
    return menue

app.jinja_env.globals.update(get_topmenue=get_topmenue)


@babel.localeselector
def get_locale():
    """ToDo: if translation is completed, switch to en """
    return LANGUAGE_SELECTED or request.accept_languages.best_match(LANGUAGES.keys()) or 'de'


@app.route("/")
@app.route("/index")
def index():
    saying, author = get_saying()
    return render_template("/index.html",
                           saying=saying,
                           author=author,
                           eskp_info=_(u'About ESKP'),
                           )

@app.route('/de')
def de():
    global LANGUAGE_SELECTED
    LANGUAGE_SELECTED = "de"
    saying, author = get_saying()
    return render_template("/index.html",
                           saying=saying,
                           author=author,
                           eskp_info=_(u'About ESKP'),
                           )

@app.route('/en')
def en():
    saying, author = get_saying()
    global LANGUAGE_SELECTED
    LANGUAGE_SELECTED = "en"
    return render_template("/index.html",
                           saying=saying,
                           author=author,
                           eskp_info=_(u'About ESKP'),
                           )

@app.route("/eskp")
def eskp():
    filename = os.path.join("templates", get_locale(), "rst", "eskp.rst")
    content = get_content(filename)
    return render_template("/content.html", act="eskp", content=content)

@app.route("/ozoneloss")
def task():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss.rst")
    content = get_content(filename)
    print content
    print filename
    return render_template("/content.html", act="ozoneloss", content=content)

@app.route("/iek-7")
def submission():
    filename = os.path.join("templates", get_locale(), "rst", "iek-7.rst")
    content = get_content(filename)
    return render_template("/content.html", act="submission", content=content)


@app.route("/imprint")
def imprint():
    filename = os.path.join("templates", get_locale(), "rst", "imprint.rst")
    content = get_content(filename)
    return render_template("/content.html", act="imprint", content=content)



@app.errorhandler(404)
def page_not_found(e):
    msg = _(u"Url: %(url)s not found", url=request.url)
    info = _(u"This information is not available!")
    return render_template("404.html", msg=msg, info=info)

if __name__ == "__main__":
    app.run(host='localhost', port=5014, debug=True)
